@@ -244,6 +244,15 @@ def _get_value(data: MultiDict, name: str, arg_spec: ArgumentSpecification):
 
     use_default, value = result
 
+    # 特别地，针对枚举类型，传入空时使用默认值
+    if arg_spec.is_type(Enum):
+        if isinstance(value, list):
+            temp = value[-1]
+        else:
+            temp = value
+        if temp is None or temp == '':
+            return True, arg_spec.default
+
     if use_default is not False:
         return result
 
@@ -304,7 +313,7 @@ def _get_input_value(arg_spec, arg_name, arg_value, config):
         return BadRequest(msg)
 
     # 当声明的参数类型是枚举类型时，遍历枚举项，同时将枚举名称与值进行处理
-    if issubclass(arg_spec.annotation, Enum):
+    if arg_spec.is_type(Enum):
         result = _get_enum_value(arg_spec, arg_value)
         if result is None:
             msg = 'Cannot parse value "%s" as type "%s" for parameter "%s".' % (
@@ -316,7 +325,7 @@ def _get_input_value(arg_spec, arg_name, arg_value, config):
         return result
 
     # 声明的类型为 IParam，调用  parse 进行转换
-    if issubclass(arg_spec.annotation, IParam):
+    if arg_spec.is_type(IParam):
         result = arg_spec.annotation.parse(arg_value)
         return result
 
